diff --git a/dumux/decoupled/common/fv/mpfa/fvmpfaproperties.hh b/dumux/decoupled/common/fv/mpfa/fvmpfaproperties.hh
index 9156438317ac63ce60e3e756e84414ed98b1c3de..6f8807c72a3c5c4cf35cd769cf6c05def130da58 100644
--- a/dumux/decoupled/common/fv/mpfa/fvmpfaproperties.hh
+++ b/dumux/decoupled/common/fv/mpfa/fvmpfaproperties.hh
@@ -30,10 +30,7 @@
 // dumux environment
 #include <dumux/decoupled/common/decoupledproperties.hh>
 #include <dune/grid/yaspgrid.hh>
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/2d/alugrid.hh>
-#include <dune/grid/alugrid/3d/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #endif
 #if HAVE_UG
@@ -72,7 +69,7 @@ struct GridImp<Dune::YaspGrid<dim>, dim>
     static const int imp = GridTypes::yaspGrid;
 };
 
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 template<int dim>
 struct GridImp<Dune::ALUGrid<dim, dim, Dune::cube, Dune::nonconforming>, dim>
 {
diff --git a/dumux/io/adaptivegridrestart.hh b/dumux/io/adaptivegridrestart.hh
index 8ee51966e699e3287d5eddb27117a3a34c733ca7..429e83fdab986db823519dc36ffe656c22de904d 100644
--- a/dumux/io/adaptivegridrestart.hh
+++ b/dumux/io/adaptivegridrestart.hh
@@ -25,10 +25,7 @@
 
 #include <dune/common/version.hh>
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/2d/alugrid.hh>
-#include <dune/grid/alugrid/3d/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #endif
 #if HAVE_ALBERTA
@@ -56,7 +53,7 @@ struct GridRestartCheck
 };
 
 // the specializations for grid managers that support restart
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 template<int dim, int dimworld, Dune::ALUGridElementType elType, Dune::ALUGridRefinementType refinementType>
 struct GridRestartCheck<Dune::ALUGrid<dim, dimworld, elType, refinementType> >
 {
@@ -88,7 +85,7 @@ public:
     static void serializeGrid(Problem& problem)
     {
         DUNE_THROW(Dune::NotImplemented,
-                   "Adaptive restart functionality currently only works for ALUGrid / dune-alugrid.");
+                   "Adaptive restart functionality currently only works for dune-ALUGrid.");
     }
 
     /*!
@@ -98,7 +95,7 @@ public:
     static void restartGrid(Problem& problem)
     {
         DUNE_THROW(Dune::NotImplemented,
-                   "Adaptive restart functionality currently only works for ALUGrid / dune-alugrid.");
+                   "Adaptive restart functionality currently only works for dune-ALUGrid.");
     }
 };
 
@@ -133,13 +130,7 @@ public:
      */
     template<class Problem>
     static void restartGrid(Problem& problem)
-    {
-#if HAVE_ALUGRID
-        std::string gridName = restartGridFileName_(problem);
-        double time = problem.timeManager().time();
-        problem.grid().template readGrid<Dune::xdr>(gridName, time);
-#endif
-    }
+    {}
 
 private:
     //! \brief Return the restart file name.
diff --git a/dumux/io/gridcreator.hh b/dumux/io/gridcreator.hh
index 3d6e7e8a7c97fde895d63b60d992b9258b61b13b..e60d99713fff5572b200c14f3e9d5379e068f92e 100644
--- a/dumux/io/gridcreator.hh
+++ b/dumux/io/gridcreator.hh
@@ -56,11 +56,6 @@
 #include <dune/alugrid/grid.hh>
 #include <dune/alugrid/dgf.hh>
 #endif
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/3d/alugrid.hh>
-#include <dune/grid/alugrid/2d/alugrid.hh>
-#include <dune/grid/io/file/dgfparser/dgfalu.hh>
-#endif
 
 // FoamGrid specific includes
 #if HAVE_DUNE_FOAMGRID
@@ -813,7 +808,7 @@ private:
 
 #endif // HAVE_UG
 
-#if HAVE_DUNE_ALUGRID || HAVE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 
 /*!
  * \brief Provides a grid creator for Dune ALUGrids
@@ -906,7 +901,7 @@ public:
     }
 };
 
-#endif // HAVE_DUNE_ALUGRID || HAVE_ALUGRID
+#endif // HAVE_DUNE_ALUGRID
 
 #if HAVE_DUNE_FOAMGRID
 
diff --git a/test/decoupled/1p/test_diffusion3d.cc b/test/decoupled/1p/test_diffusion3d.cc
index fad45f6d5a0a647f6dda6c905a841d1ef18deaa7..fc3298c1f444d3e871441334c2bb345fb28efe5e 100644
--- a/test/decoupled/1p/test_diffusion3d.cc
+++ b/test/decoupled/1p/test_diffusion3d.cc
@@ -25,7 +25,7 @@
 #include "config.h"
 #include <iostream>
 
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG
+#if HAVE_DUNE_ALUGRID || HAVE_UG
 
 #include <dune/common/exceptions.hh>
 #include <dune/common/parallel/mpihelper.hh>
@@ -231,4 +231,4 @@ int main()
     std::cerr << "You need to have dune-ALUGrid or UG installed to run this test\n";
     return 77;
 }
-#endif // HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG
+#endif // HAVE_DUNE_ALUGRID || HAVE_UG
diff --git a/test/decoupled/1p/test_diffusionproblem3d.hh b/test/decoupled/1p/test_diffusionproblem3d.hh
index 8cee46df6f072261a4cc6eb1d85a3ad581f3bea7..606a38e63be6d14ac9a68484668ddee95a138c35 100644
--- a/test/decoupled/1p/test_diffusionproblem3d.hh
+++ b/test/decoupled/1p/test_diffusionproblem3d.hh
@@ -22,11 +22,9 @@
 #ifndef DUMUX_TEST_DIFFUSION_3D_PROBLEM_HH
 #define DUMUX_TEST_DIFFUSION_3D_PROBLEM_HH
 
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG
+#if HAVE_DUNE_ALUGRID || HAVE_UG
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/3d/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #endif
 #include <dune/grid/uggrid.hh>
@@ -57,7 +55,7 @@ namespace Properties
 NEW_TYPE_TAG(DiffusionTestProblem, INHERITS_FROM(DecoupledTwoP, TestDiffusionSpatialParams3d));
 
 // Set the grid type
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(DiffusionTestProblem, Grid, Dune::ALUGrid<3, 3, Dune::cube, Dune::nonconforming>);
 #else
 SET_TYPE_PROP(DiffusionTestProblem, Grid, Dune::UGGrid<3>);
@@ -270,6 +268,6 @@ private:
 };
 } //end namespace
 
-#endif // HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UGGRID
+#endif // HAVE_DUNE_ALUGRID || HAVE_UGGRID
 
 #endif
diff --git a/test/decoupled/2p/test_3d2p.cc b/test/decoupled/2p/test_3d2p.cc
index 1ce5d767b726569d2662fb9deaaec8e4d84b31b9..4c737b84a712198f1c73d0e0c5a8c9a3ad1e415c 100644
--- a/test/decoupled/2p/test_3d2p.cc
+++ b/test/decoupled/2p/test_3d2p.cc
@@ -23,7 +23,7 @@
 
 #include "config.h"
 
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 
 #include "test_3d2pproblem.hh"
 #include <dumux/common/start.hh>
diff --git a/test/decoupled/2p/test_3d2pproblem.hh b/test/decoupled/2p/test_3d2pproblem.hh
index b27bcac32b7f8f08ffb4e4f22a3e0f179c3e5020..99eb3ec3b1d80e3beaf3228f1d14b7c92d5723c3 100644
--- a/test/decoupled/2p/test_3d2pproblem.hh
+++ b/test/decoupled/2p/test_3d2pproblem.hh
@@ -24,9 +24,7 @@
 #ifndef DUMUX_TEST_3D2P_PROBLEM_HH
 #define DUMUX_TEST_3D2P_PROBLEM_HH
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/3d/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #endif
 
@@ -64,7 +62,7 @@ namespace Properties
 NEW_TYPE_TAG(ThreeDTwoPTestProblem, INHERITS_FROM(Test3d2pSpatialParams));
 
 // Set the grid type
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(ThreeDTwoPTestProblem, Grid, Dune::ALUGrid<3, 3, Dune::cube, Dune::nonconforming>);
 #endif
 
diff --git a/test/decoupled/2p/test_impesadaptive.cc b/test/decoupled/2p/test_impesadaptive.cc
index 03c5ceedab8ba8e30088f7e89010e0b847c5f230..d328b4b0e585e0e23f925fa78443a3824c498f53 100644
--- a/test/decoupled/2p/test_impesadaptive.cc
+++ b/test/decoupled/2p/test_impesadaptive.cc
@@ -24,7 +24,7 @@
  */
 #include "config.h"
 
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 
 #include "test_impesadaptiveproblem.hh"
 #include <dumux/common/start.hh>
@@ -68,4 +68,4 @@ int main()
     std::cerr << "You need to have dune-ALUGrid installed to run this test\n";
     return 77;
 }
-#endif // HAVE_ALUGRID
+#endif // HAVE_DUNE_ALUGRID
diff --git a/test/decoupled/2p/test_impesadaptiveproblem.hh b/test/decoupled/2p/test_impesadaptiveproblem.hh
index 3b9723b8024631d1e18ac0c877526e7fffeeabf1..6d8f38d2dd870c025285619fc28553f9aacd4761 100644
--- a/test/decoupled/2p/test_impesadaptiveproblem.hh
+++ b/test/decoupled/2p/test_impesadaptiveproblem.hh
@@ -24,9 +24,7 @@
 #ifndef DUMUX_TEST_IMPES_ADAPTIVE_PROBLEM_HH
 #define DUMUX_TEST_IMPES_ADAPTIVE_PROBLEM_HH
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/2d/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #endif
 
@@ -59,7 +57,7 @@ NEW_TYPE_TAG(TestIMPESAdaptiveProblem, INHERITS_FROM(FVPressureTwoPAdaptive, FVT
 NEW_TYPE_TAG(TestIMPESAdaptiveRestartProblem, INHERITS_FROM(TestIMPESAdaptiveProblem));
 
 // Set the grid type
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(TestIMPESAdaptiveProblem, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #endif
 
diff --git a/test/decoupled/2p/test_impesadaptiverestart.cc b/test/decoupled/2p/test_impesadaptiverestart.cc
index 379809d0835014cbfef4acbc9974e58216e9d7ca..0468a54939e895be8ea8f997918a41a630d18a45 100644
--- a/test/decoupled/2p/test_impesadaptiverestart.cc
+++ b/test/decoupled/2p/test_impesadaptiverestart.cc
@@ -24,7 +24,7 @@
  */
 #include "config.h"
 
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 
 #include "test_impesadaptiveproblem.hh"
 #include <dumux/common/start.hh>
@@ -42,12 +42,6 @@ void usage(const char *progName, const std::string &errorMsg)
                     errorMessageOut += "\n\nThe list of mandatory options for this program is:\n"
                                        "\t-TimeManager.TEnd      End of the simulation [s] \n"
                                        "\t-TimeManager.DtInitial Initial timestep size [s] \n"
-#if HAVE_ALUGRID
-                                       "\t-Grid.NumberOfCellsX   Resolution in x-direction [-]\n"
-                                       "\t-Grid.NumberOfCellsY   Resolution in y-direction [-]\n"
-                                       "\t-Grid.UpperRightX      Length of the domain [m]\n"
-                                       "\t-Grid.UpperRightY      Height of the domain [m]\n"
-#endif
                                        "\t-Problem.Name          Name passed to the output routines \n"
                                        "\t-Restart               Restart time [s] \n";
         std::cout << errorMessageOut
@@ -70,4 +64,4 @@ int main()
     std::cerr << "You need to have dune-ALUGrid installed to run this test\n";
     return 77;
 }
-#endif // HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#endif // HAVE_DUNE_ALUGRID
diff --git a/test/decoupled/2p/test_mpfa2p.cc b/test/decoupled/2p/test_mpfa2p.cc
index 0029b8afa18b737e4d93f040696edb53db483eab..d3a15cc72e60a438ffcd506c41bba3caa9b30faf 100644
--- a/test/decoupled/2p/test_mpfa2p.cc
+++ b/test/decoupled/2p/test_mpfa2p.cc
@@ -23,7 +23,7 @@
 
 #include "config.h"
 
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 
 #include "test_mpfa2pproblem.hh"
 #include <dumux/common/start.hh>
diff --git a/test/decoupled/2p/test_mpfa2pproblem.hh b/test/decoupled/2p/test_mpfa2pproblem.hh
index afb2d6faac0e6bd852c923dd6b651649e56864c7..326a876bba4fe1c53341e69cc8eecdd8ffecd7a7 100644
--- a/test/decoupled/2p/test_mpfa2pproblem.hh
+++ b/test/decoupled/2p/test_mpfa2pproblem.hh
@@ -24,9 +24,7 @@
 #ifndef DUMUX_TEST_MPFA2P_PROBLEM_HH
 #define DUMUX_TEST_MPFA2P_PROBLEM_HH
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/2d/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #endif
 
@@ -67,7 +65,7 @@ namespace Properties
 NEW_TYPE_TAG(MPFATwoPTestProblem, INHERITS_FROM(Test2PSpatialParams));
 
 // Set the grid type
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(MPFATwoPTestProblem, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #endif
 
diff --git a/test/decoupled/2p2c/test_adaptive2p2c2dproblem.hh b/test/decoupled/2p2c/test_adaptive2p2c2dproblem.hh
index 8899d795c5bc9c763da28b641152823e18036a49..5ea824b0e786eb4afc128fd56dd399f7cd28a89d 100644
--- a/test/decoupled/2p2c/test_adaptive2p2c2dproblem.hh
+++ b/test/decoupled/2p2c/test_adaptive2p2c2dproblem.hh
@@ -24,9 +24,7 @@
 #ifndef DUMUX_TEST_ADAPTIVE2D_2P2C_PROBLEM_HH
 #define DUMUX_TEST_ADAPTIVE2D_2P2C_PROBLEM_HH
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #else
 #include <dune/grid/yaspgrid.hh>
@@ -55,7 +53,7 @@ namespace Properties
 NEW_TYPE_TAG(Adaptive2p2c2d, INHERITS_FROM(DecoupledTwoPTwoCAdaptive,Test2P2CSpatialParams));
 
 // Set the grid type
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(Adaptive2p2c2d, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #else
 SET_TYPE_PROP(Adaptive2p2c2d, Grid, Dune::YaspGrid<2>);
diff --git a/test/decoupled/2p2c/test_adaptive2p2c3d.cc b/test/decoupled/2p2c/test_adaptive2p2c3d.cc
index 4c35be3f839b8d425e4ba8673cda8edfc40732b0..461f2cb2eba2da055d3cc9641f95265b5f84ea6e 100644
--- a/test/decoupled/2p2c/test_adaptive2p2c3d.cc
+++ b/test/decoupled/2p2c/test_adaptive2p2c3d.cc
@@ -23,7 +23,7 @@
  */
 #include "config.h"
 
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 
 #include "test_adaptive2p2c3dproblem.hh"
 #include <dumux/common/start.hh>
@@ -71,4 +71,4 @@ int main()
     std::cerr << "You need to have dune-ALUGrid installed to run this test\n";
     return 77;
 }
-#endif // HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#endif // HAVE_DUNE_ALUGRID
diff --git a/test/decoupled/2p2c/test_adaptive2p2c3dproblem.hh b/test/decoupled/2p2c/test_adaptive2p2c3dproblem.hh
index df4651ad8264045345f79331b83e4de3564890a3..690e749235b8f2797599fbe19400bda69bcb8a0d 100644
--- a/test/decoupled/2p2c/test_adaptive2p2c3dproblem.hh
+++ b/test/decoupled/2p2c/test_adaptive2p2c3dproblem.hh
@@ -24,9 +24,7 @@
 #ifndef DUMUX_TEST_ADAPTIVE3D_2P2C_PROBLEM_HH
 #define DUMUX_TEST_ADAPTIVE3D_2P2C_PROBLEM_HH
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #else
 #include <dune/grid/yaspgrid.hh>
@@ -53,7 +51,7 @@ namespace Properties
 NEW_TYPE_TAG(Adaptive2p2c3d, INHERITS_FROM(DecoupledTwoPTwoCAdaptive,Test2P2CSpatialParams, MPFAProperties));
 
 // Set the grid type
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(Adaptive2p2c3d, Grid, Dune::ALUGrid<3, 3, Dune::cube, Dune::nonconforming>);
 #else
 SET_TYPE_PROP(Adaptive2p2c3d, Grid, Dune::YaspGrid<3>);
diff --git a/test/freeflow/navierstokes/navierstokestestproblem.hh b/test/freeflow/navierstokes/navierstokestestproblem.hh
index e7e0b86bf79c3368110deaf486328f185fe5f82c..175db8b581b7992cd23df4d2c41f33c1ea953e5c 100644
--- a/test/freeflow/navierstokes/navierstokestestproblem.hh
+++ b/test/freeflow/navierstokes/navierstokestestproblem.hh
@@ -23,9 +23,7 @@
 #ifndef DUMUX_TEST_FREEFLOW_NAVIERSTOKESTESTPROBLEM_HH
 #define DUMUX_TEST_FREEFLOW_NAVIERSTOKESTESTPROBLEM_HH
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/2d/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #elif HAVE_UG
 #include <dune/grid/io/file/dgfparser/dgfug.hh>
@@ -52,7 +50,7 @@ namespace Dumux
     NEW_TYPE_TAG(NavierStokesTestProblem, INHERITS_FROM(BoxStokes));
 
     // Set the grid type
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
     SET_TYPE_PROP(NavierStokesTestProblem, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #elif HAVE_UG
     SET_TYPE_PROP(NavierStokesTestProblem, Grid, Dune::UGGrid<2>);
diff --git a/test/freeflow/navierstokes/test_navierstokes.cc b/test/freeflow/navierstokes/test_navierstokes.cc
index c77ff0ae6da81b326d3b734cc8d7b2aba2a7a33b..79f480ec43dd9d808e1bf95adb975d5bf3074c6b 100644
--- a/test/freeflow/navierstokes/test_navierstokes.cc
+++ b/test/freeflow/navierstokes/test_navierstokes.cc
@@ -51,7 +51,7 @@ void usage(const char *progName, const std::string &errorMsg)
 
 int main(int argc, char** argv)
 {
-#if HAVE_SUPERLU && (HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
+#if HAVE_SUPERLU && (HAVE_DUNE_ALUGRID || HAVE_UG)
     typedef TTAG(NavierStokesTestProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
diff --git a/test/implicit/1p/1ptestproblem.hh b/test/implicit/1p/1ptestproblem.hh
index 9fb0b9e4d5d8be1c8ffdc5e8d071fe7af6c610c3..7501c07ef427ceca8936b6d77b224e6aff8cd8fe 100644
--- a/test/implicit/1p/1ptestproblem.hh
+++ b/test/implicit/1p/1ptestproblem.hh
@@ -28,9 +28,7 @@
 #if HAVE_UG
 #include <dune/grid/io/file/dgfparser/dgfug.hh>
 #endif
-#if HAVE_ALUGRID
-#include <dune/grid/io/file/dgfparser/dgfalu.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #endif
 #include <dune/grid/io/file/dgfparser/dgfyasp.hh>
diff --git a/test/implicit/2p/lensproblem.hh b/test/implicit/2p/lensproblem.hh
index 3e57c668f9d496c23b56586d540ca14eafc6ee2f..0bc9fddd61091aaad8f6e4a865dbc373c8186366 100644
--- a/test/implicit/2p/lensproblem.hh
+++ b/test/implicit/2p/lensproblem.hh
@@ -26,9 +26,7 @@
 #ifndef DUMUX_LENSPROBLEM_HH
 #define DUMUX_LENSPROBLEM_HH
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/2d/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #endif
 
@@ -73,7 +71,7 @@ SET_TYPE_PROP(LensCCProblem, Grid, Dune::YaspGrid<2>);
 SET_TYPE_PROP(LensBoxProblem, Grid, Dune::YaspGrid<2>);
 #endif
 
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(LensBoxAdaptiveProblem, Grid, Dune::ALUGrid<2, 2, Dune::simplex, Dune::conforming>);
 SET_TYPE_PROP(LensCCAdaptiveProblem, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #endif
@@ -102,7 +100,7 @@ public:
 // Linear solver settings
 SET_TYPE_PROP(LensCCProblem, LinearSolver, Dumux::BoxBiCGStabILU0Solver<TypeTag> );
 SET_TYPE_PROP(LensBoxProblem, LinearSolver, Dumux::BoxBiCGStabILU0Solver<TypeTag> );
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(LensCCAdaptiveProblem, LinearSolver, Dumux::ILU0BiCGSTABBackend<TypeTag> );
 SET_TYPE_PROP(LensBoxAdaptiveProblem, LinearSolver, Dumux::ILU0BiCGSTABBackend<TypeTag> );
 
@@ -118,7 +116,7 @@ SET_TYPE_PROP(LensBoxAdaptiveProblem,  AdaptionInitializationIndicator, Implicit
 NEW_PROP_TAG(BaseProblem);
 SET_TYPE_PROP(LensBoxProblem, BaseProblem, ImplicitPorousMediaProblem<TypeTag>);
 SET_TYPE_PROP(LensCCProblem, BaseProblem, ImplicitPorousMediaProblem<TypeTag>);
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(LensCCAdaptiveProblem, BaseProblem, ImplicitPorousMediaProblem<TypeTag>);
 SET_TYPE_PROP(LensBoxAdaptiveProblem, BaseProblem, ImplicitPorousMediaProblem<TypeTag>);
 #endif
diff --git a/test/implicit/2p/test_boxadaptive2p.cc b/test/implicit/2p/test_boxadaptive2p.cc
index 2fa81283372bb497d4510ef86f317f1e3a0cef71..bf81b73c1759285d015fe619e0537e56711c36a3 100644
--- a/test/implicit/2p/test_boxadaptive2p.cc
+++ b/test/implicit/2p/test_boxadaptive2p.cc
@@ -61,7 +61,7 @@ void usage(const char *progName, const std::string &errorMsg)
 ////////////////////////
 int main(int argc, char** argv)
 {
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
     typedef TTAG(LensBoxAdaptiveProblem) TypeTag;
     return Dumux::start<TypeTag>(argc, argv, usage);
 #else
diff --git a/test/implicit/2p/test_ccadaptive2p.cc b/test/implicit/2p/test_ccadaptive2p.cc
index 639c50e43e59f8db9f5dc45702e0833294063d5f..78b3f0ca7d770aa7fa3b59fc99047ed34501449a 100644
--- a/test/implicit/2p/test_ccadaptive2p.cc
+++ b/test/implicit/2p/test_ccadaptive2p.cc
@@ -62,7 +62,7 @@ void usage(const char *progName, const std::string &errorMsg)
 int main(int argc, char** argv)
 {
 
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
     typedef TTAG(LensCCAdaptiveProblem) TypeTag;
     return Dumux::start<TypeTag>(argc, argv, usage);
 #else
diff --git a/test/implicit/co2/heterogeneousproblem.hh b/test/implicit/co2/heterogeneousproblem.hh
index 1e29643e21bdcf248207d3dccfb51b83f30fa1cd..4b512cba09a82e7804988e0c7599c10833ce7a8a 100644
--- a/test/implicit/co2/heterogeneousproblem.hh
+++ b/test/implicit/co2/heterogeneousproblem.hh
@@ -24,9 +24,7 @@
 #ifndef DUMUX_HETEROGENEOUS_PROBLEM_HH
 #define DUMUX_HETEROGENEOUS_PROBLEM_HH
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/2d/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #else
 #warning ALUGrid is necessary for this test.
@@ -56,7 +54,7 @@ NEW_TYPE_TAG(HeterogeneousBoxProblem, INHERITS_FROM(BoxModel, HeterogeneousProbl
 NEW_TYPE_TAG(HeterogeneousCCProblem, INHERITS_FROM(CCModel, HeterogeneousProblem));
 
 // Set the grid type
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(HeterogeneousProblem, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #else
 SET_TYPE_PROP(HeterogeneousProblem, Grid, Dune::YaspGrid<2>);
diff --git a/test/implicit/co2/heterogeneousproblemni.hh b/test/implicit/co2/heterogeneousproblemni.hh
index 2ecfa6d60ec0fa1d878218316e4196a17ae1e7fd..65a8271f8cda676bd70446321d28798a26dc9d1b 100644
--- a/test/implicit/co2/heterogeneousproblemni.hh
+++ b/test/implicit/co2/heterogeneousproblemni.hh
@@ -24,9 +24,7 @@
 #ifndef DUMUX_HETEROGENEOUS_PROBLEM_NI_HH
 #define DUMUX_HETEROGENEOUS_PROBLEM_NI_HH
 
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid/2d/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #else
 #warning ALUGrid is necessary for this test.
@@ -56,7 +54,7 @@ NEW_TYPE_TAG(HeterogeneousNICCProblem, INHERITS_FROM(CCModel, HeterogeneousNIPro
 
 
 // Set the grid type
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(HeterogeneousNIProblem, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #else
 SET_TYPE_PROP(HeterogeneousNIProblem, Grid, Dune::YaspGrid<2>);
diff --git a/test/implicit/co2/test_boxco2.cc b/test/implicit/co2/test_boxco2.cc
index b992b93c18941915cb920af7ad99e173e68db909..a537f6902cee4692e83cee2203f4222211dc4951 100644
--- a/test/implicit/co2/test_boxco2.cc
+++ b/test/implicit/co2/test_boxco2.cc
@@ -70,7 +70,7 @@ int main(int argc, char** argv)
 #warning Test needs experimental grid extensions.
     std::cerr << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
     return 77;
-#elif !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID)
+#elif !HAVE_DUNE_ALUGRID
 #warning You need to have dune-ALUGrid installed to run this test.
     std::cerr << "You need to have dune-ALUGrid installed to run this test." << std::endl;
     return 77;
diff --git a/test/implicit/co2/test_boxco2ni.cc b/test/implicit/co2/test_boxco2ni.cc
index 86004ef0048c06d2f58fd767d7ebd80690984c4b..e4288d773b0d043480f12263b6d3638ce1c4591b 100644
--- a/test/implicit/co2/test_boxco2ni.cc
+++ b/test/implicit/co2/test_boxco2ni.cc
@@ -71,7 +71,7 @@ int main(int argc, char** argv)
 #warning Test needs experimental grid extensions.
     std::cerr << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
     return 77;
-#elif !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID)
+#elif !HAVE_DUNE_ALUGRID
 #warning You need to have dune-ALUGrid installed to run this test.
     std::cerr << "You need to have dune-ALUGrid installed to run this test." << std::endl;
     return 77;
diff --git a/test/implicit/co2/test_ccco2.cc b/test/implicit/co2/test_ccco2.cc
index b3eacc9a74fc8cce9dcd64e4fb22b3829050955b..9cb98984dc9dd5b0b9a37e7136696c18f72c287c 100644
--- a/test/implicit/co2/test_ccco2.cc
+++ b/test/implicit/co2/test_ccco2.cc
@@ -70,7 +70,7 @@ int main(int argc, char** argv)
 #warning Test needs experimental grid extensions.
     std::cerr << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
     return 77;
-#elif !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID)
+#elif !HAVE_DUNE_ALUGRID
 #warning You need to have dune-ALUGrid installed to run this test.
     std::cerr << "You need to have dune-ALUGrid installed to run this test." << std::endl;
     return 77;
diff --git a/test/implicit/co2/test_ccco2ni.cc b/test/implicit/co2/test_ccco2ni.cc
index e7e591ab3ad81f4e816e1867d03ee75adc41ebee..b0e0e6bde42f7825cdd6e36b9da5bdd7737e465b 100644
--- a/test/implicit/co2/test_ccco2ni.cc
+++ b/test/implicit/co2/test_ccco2ni.cc
@@ -71,7 +71,7 @@ int main(int argc, char** argv)
 #warning Test needs experimental grid extensions.
     std::cerr << "Test skipped, it needs experimental grid extensions, see optim.opts or debug.opts." << std::endl;
     return 77;
-#elif !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID)
+#elif !HAVE_DUNE_ALUGRID
 #warning You need to have dune-ALUGrid installed to run this test.
     std::cerr << "You need to have dune-ALUGrid installed to run this test." << std::endl;
     return 77;
diff --git a/test/implicit/mpnc/evaporationatmosphereproblem.hh b/test/implicit/mpnc/evaporationatmosphereproblem.hh
index 656f4bfb52b376c85eddc6c5b8d670165b3939ea..3706d14def88d54ede84663c765338d5d190b854 100644
--- a/test/implicit/mpnc/evaporationatmosphereproblem.hh
+++ b/test/implicit/mpnc/evaporationatmosphereproblem.hh
@@ -50,9 +50,7 @@
 
 #include <dune/grid/io/file/dgfparser/dgfug.hh>
 #include <dune/grid/io/file/dgfparser/dgfyasp.hh>
-#ifdef HAVE_ALUGRID
-#include <dune/grid/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #endif
 
@@ -87,7 +85,7 @@ NEW_TYPE_TAG(EvaporationAtmosphereProblem,
 // Set the grid type
 SET_PROP(EvaporationAtmosphereProblem, Grid)
 {
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
     typedef typename Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming> type;
 #else
     typedef typename Dune::UGGrid<2> type;
diff --git a/test/implicit/mpnc/test_boxmpnckinetic.cc b/test/implicit/mpnc/test_boxmpnckinetic.cc
index ad075f1539fb8ca1ae132dcf24f7821d6b8b9711..5f5b96a13fc7f63fa4f0dad95fa31ea1f6497c33 100644
--- a/test/implicit/mpnc/test_boxmpnckinetic.cc
+++ b/test/implicit/mpnc/test_boxmpnckinetic.cc
@@ -61,7 +61,7 @@ void printUsage(const char *progName, const std::string &errorMsg)
 
 int main(int argc, char** argv)
 {
-#if !HAVE_UG && !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID)
+#if !HAVE_UG && !HAVE_DUNE_ALUGRID
 #warning Evaporation Atmosphere not built, needs either UG or dune-ALUGrid for the log mesh.
     std::cerr << "Evaporation Atmosphere not built, needs either UG or dune-ALUGrid for the log mesh." << std::endl;
     return 77;
diff --git a/test/multidomain/2cnistokes2p2cni/2cnistokes2p2cniproblem.hh b/test/multidomain/2cnistokes2p2cni/2cnistokes2p2cniproblem.hh
index a668099f10bb580b3924424f23a93264ddb41730..fcb994bc0c1e53237fc519fbcf2cb0eadbb6e5ab 100644
--- a/test/multidomain/2cnistokes2p2cni/2cnistokes2p2cniproblem.hh
+++ b/test/multidomain/2cnistokes2p2cni/2cnistokes2p2cniproblem.hh
@@ -64,7 +64,7 @@ NEW_TYPE_TAG(TwoCNIStokesTwoPTwoCNIProblem, INHERITS_FROM(TwoCNIStokesTwoPTwoCNI
 // Set the grid type
 #ifdef HAVE_UG
 SET_TYPE_PROP(TwoCNIStokesTwoPTwoCNIProblem, Grid, Dune::UGGrid<2>);
-#elif HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#elif HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(TwoCNIStokesTwoPTwoCNIProblem, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #else
 SET_TYPE_PROP(TwoCNIStokesTwoPTwoCNIProblem, Grid, Dune::YaspGrid<2>);
diff --git a/test/multidomain/2cnizeroeq2p2cni/2cnizeroeq2p2cniproblem.hh b/test/multidomain/2cnizeroeq2p2cni/2cnizeroeq2p2cniproblem.hh
index 81844d541737bfa9c9b574da685ebcfaca30625f..bce732ddc2e337695f0d112d48926752c4d00195 100644
--- a/test/multidomain/2cnizeroeq2p2cni/2cnizeroeq2p2cniproblem.hh
+++ b/test/multidomain/2cnizeroeq2p2cni/2cnizeroeq2p2cniproblem.hh
@@ -50,10 +50,10 @@ NEW_TYPE_TAG(TwoCNIZeroEqTwoPTwoCNIProblem, INHERITS_FROM(TwoCNIStokesTwoPTwoCNI
 // Set the grid type
 #if HAVE_UG
 SET_TYPE_PROP(TwoCNIZeroEqTwoPTwoCNIProblem, Grid, Dune::UGGrid<2>);
-#elif HAVE_ALUGRID
+#elif HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(TwoCNIZeroEqTwoPTwoCNIProblem, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #else
-#error Requires UG or ALUGrid.
+SET_TYPE_PROP(TwoCNIZeroEqTwoPTwoCNIProblem, Grid, Dune::YaspGrid<2>);
 #endif
 
 // Set the global problem
diff --git a/test/multidomain/2cstokes2p2c/2cstokes2p2cproblem.hh b/test/multidomain/2cstokes2p2c/2cstokes2p2cproblem.hh
index 8ca5e58e82b27fff0fb147b26b36a268b9039477..6f4f6f137c44059e9976174702d73d0acc1abe9d 100644
--- a/test/multidomain/2cstokes2p2c/2cstokes2p2cproblem.hh
+++ b/test/multidomain/2cstokes2p2c/2cstokes2p2cproblem.hh
@@ -63,7 +63,7 @@ NEW_TYPE_TAG(TwoCStokesTwoPTwoCProblem, INHERITS_FROM(TwoCStokesTwoPTwoC));
 // Set the grid type
 #ifdef HAVE_UG
 SET_TYPE_PROP(TwoCStokesTwoPTwoCProblem, Grid, Dune::UGGrid<2>);
-#elif HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#elif HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(TwoCStokesTwoPTwoCProblem, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #else
 SET_TYPE_PROP(TwoCStokesTwoPTwoCProblem, Grid, Dune::YaspGrid<2>);
diff --git a/test/multidomain/2czeroeq2p2c/2czeroeq2p2cproblem.hh b/test/multidomain/2czeroeq2p2c/2czeroeq2p2cproblem.hh
index df8eda846e33a91701ce4fcdcf7315503ce9d054..301f34a5d0e94c69167ccbe3fcbbee195731fbab 100644
--- a/test/multidomain/2czeroeq2p2c/2czeroeq2p2cproblem.hh
+++ b/test/multidomain/2czeroeq2p2c/2czeroeq2p2cproblem.hh
@@ -50,10 +50,10 @@ NEW_TYPE_TAG(TwoCZeroEqTwoPTwoCProblem, INHERITS_FROM(TwoCStokesTwoPTwoC));
 // Set the grid type
 #if HAVE_UG
 SET_TYPE_PROP(TwoCZeroEqTwoPTwoCProblem, Grid, Dune::UGGrid<2>);
-#elif HAVE_ALUGRID
+#elif HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(TwoCZeroEqTwoPTwoCProblem, Grid, Dune::ALUGrid<2, 2, Dune::cube, Dune::nonconforming>);
 #else
-#error Requires UG or ALUGrid.
+SET_TYPE_PROP(TwoCStokesTwoPTwoCProblem, Grid, Dune::YaspGrid<2>);
 #endif
 
 // Set the global problem
diff --git a/tutorial/solutions_coupled/ex1c_tutorialproblem_coupled.diff b/tutorial/solutions_coupled/ex1c_tutorialproblem_coupled.diff
index c7bcf563dbdcb83bf677598d3c4baa3247c9f161..701d23e76ab5daa071384a09fe701d70a0e8ddb2 100644
--- a/tutorial/solutions_coupled/ex1c_tutorialproblem_coupled.diff
+++ b/tutorial/solutions_coupled/ex1c_tutorialproblem_coupled.diff
@@ -14,14 +14,14 @@ Index: tutorialproblem_coupled.hh
 @@ -64,13 +64,13 @@
  
  // Set grid and the grid creator to be used
- #if HAVE_ALUGRID || HAVE_DUNE_ALUGRID /*@\label{tutorial-coupled:set-grid}@*/
+ #if HAVE_DUNE_ALUGRID /*@\label{tutorial-coupled:set-grid}@*/
 -SET_TYPE_PROP(TutorialProblemCoupled, Grid, Dune::ALUGrid</*dim=*/2, 2, Dune::cube, Dune::nonconforming>); /*@\label{tutorial-coupled:set-grid-ALU}@*/
 +SET_TYPE_PROP(TutorialProblemCoupled, Grid, Dune::ALUGrid</*dim=*/2, 2, Dune::simplex, Dune::nonconforming>); /*@\label{tutorial-coupled:set-grid-ALU}@*/
  #elif HAVE_UG
  SET_TYPE_PROP(TutorialProblemCoupled, Grid, Dune::UGGrid<2>);
  #else
  SET_TYPE_PROP(TutorialProblemCoupled, Grid, Dune::YaspGrid<2>);
- #endif // HAVE_ALUGRID
+ #endif // HAVE_DUNE_ALUGRID
 -SET_TYPE_PROP(TutorialProblemCoupled, GridCreator, Dumux::CubeGridCreator<TypeTag>); /*@\label{tutorial-coupled:set-gridcreator}@*/
 +SET_TYPE_PROP(TutorialProblemCoupled, GridCreator, Dumux::SimplexGridCreator<TypeTag>); /*@\label{tutorial-coupled:set-gridcreator}@*/
  
diff --git a/tutorial/solutions_coupled/ex1e_tutorialproblem_coupled.diff b/tutorial/solutions_coupled/ex1e_tutorialproblem_coupled.diff
index 3e9c6ac0bd131907ccf28fc501d7348ca1b55ee3..5ba861bd0a95120f3d0bdf819a051da0c8c4f191 100644
--- a/tutorial/solutions_coupled/ex1e_tutorialproblem_coupled.diff
+++ b/tutorial/solutions_coupled/ex1e_tutorialproblem_coupled.diff
@@ -51,6 +51,6 @@ Index: tutorialproblem_coupled.hh
          , eps_(3e-6)
      {
 +      GET_PROP_TYPE(TypeTag, FluidSystem)::init();
- #if !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
-       std::cout << "If you want to use simplices instead of cubes, install and use ALUGrid or UGGrid." << std::endl;
- #endif // !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
+ #if !(HAVE_DUNE_ALUGRID || HAVE_UG)
+       std::cout << "If you want to use simplices instead of cubes, install and use dune-ALUGrid or UGGrid." << std::endl;
+ #endif // !(HAVE_DUNE_ALUGRID || HAVE_UG)
diff --git a/tutorial/solutions_coupled/ex2_tutorialproblem_coupled.hh b/tutorial/solutions_coupled/ex2_tutorialproblem_coupled.hh
index 95764f3df1313efe5b397adbc89af5fb696a8937..c334fa9a545056ede8e18245c28fdccbd006c643 100644
--- a/tutorial/solutions_coupled/ex2_tutorialproblem_coupled.hh
+++ b/tutorial/solutions_coupled/ex2_tutorialproblem_coupled.hh
@@ -31,15 +31,13 @@
 #include <dumux/implicit/common/implicitporousmediaproblem.hh>
 
 // The DUNE grid used
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #elif HAVE_UG
 #include <dune/grid/uggrid.hh>
 #else
 #include <dune/grid/yaspgrid.hh>
-#endif // HAVE_ALUGRID, HAVE_UG
+#endif // HAVE_DUNE_ALUGRID, HAVE_UG
 
 // Spatially dependent parameters
 #include "ex2_tutorialspatialparams_coupled.hh"
@@ -63,13 +61,13 @@ SET_PROP(Ex2TutorialProblemCoupled, Problem) /*@\label{tutorial-coupled:set-prob
 { typedef Dumux::Ex2TutorialProblemCoupled<TypeTag> type;};
 
 // Set grid and the grid creator to be used
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID /*@\label{tutorial-coupled:set-grid}@*/
+#if HAVE_DUNE_ALUGRID /*@\label{tutorial-coupled:set-grid}@*/
 SET_TYPE_PROP(Ex2TutorialProblemCoupled, Grid, Dune::ALUGrid</*dim=*/2, 2, Dune::cube, Dune::nonconforming>); /*@\label{tutorial-coupled:set-grid-ALU}@*/
 #elif HAVE_UG
 SET_TYPE_PROP(Ex2TutorialProblemCoupled, Grid, Dune::UGGrid<2>);
 #else
 SET_TYPE_PROP(Ex2TutorialProblemCoupled, Grid, Dune::YaspGrid<2>);
-#endif // HAVE_ALUGRID
+#endif // HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(Ex2TutorialProblemCoupled, GridCreator, Dumux::CubeGridCreator<TypeTag>); /*@\label{tutorial-coupled:set-gridcreator}@*/
 
 // Set the wetting phase
@@ -127,9 +125,9 @@ public:
         : ParentType(timeManager, gridView)
         , eps_(3e-6)
     {
-#if !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
+#if !(HAVE_DUNE_ALUGRID || HAVE_UG)
       std::cout << "If you want to use simplices instead of cubes, install and use ALUGrid or UGGrid." << std::endl;
-#endif // !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
+#endif // !(HAVE_DUNE_ALUGRID || HAVE_UG)
     }
 
     //! Specifies the problem name. This is used as a prefix for files
diff --git a/tutorial/solutions_coupled/ex3_tutorialproblem_coupled.diff b/tutorial/solutions_coupled/ex3_tutorialproblem_coupled.diff
index e52166d9e9492ff185650275f53b73eff5cb9155..51f31da3600ed1302b98855a56277213c9702bc2 100644
--- a/tutorial/solutions_coupled/ex3_tutorialproblem_coupled.diff
+++ b/tutorial/solutions_coupled/ex3_tutorialproblem_coupled.diff
@@ -20,9 +20,9 @@ Index: tutorialproblem_coupled.hh
 +            std::cerr << "Unknown exception thrown!\n";
 +            exit(1);
 +        }
- #if !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
+ #if !(HAVE_DUNE_ALUGRID || HAVE_UG)
        std::cout << "If you want to use simplices instead of cubes, install and use ALUGrid or UGGrid." << std::endl;
- #endif // !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
+ #endif // !(HAVE_DUNE_ALUGRID || HAVE_UG)
 @@ -194,7 +208,7 @@
          if (globalPos[0] > right - eps_) {
              // oil outflux of 30 g/(m * s) on the right boundary.
diff --git a/tutorial/tutorialproblem_coupled.hh b/tutorial/tutorialproblem_coupled.hh
index ccb81778066522e130fb574fbc8338e3f153c67d..087ca9b470acbddf038f625bff2e2f4f1af51025 100644
--- a/tutorial/tutorialproblem_coupled.hh
+++ b/tutorial/tutorialproblem_coupled.hh
@@ -31,15 +31,13 @@
 #include <dumux/implicit/common/implicitporousmediaproblem.hh>
 
 // The DUNE grid used
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if  HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #elif HAVE_UG
 #include <dune/grid/uggrid.hh>
 #else
 #include <dune/grid/yaspgrid.hh>
-#endif // HAVE_ALUGRID, HAVE_UG
+#endif // HAVE_DUNE_ALUGRID, HAVE_UG
 
 // Spatially dependent parameters
 #include "tutorialspatialparams_coupled.hh"
@@ -63,13 +61,13 @@ SET_PROP(TutorialProblemCoupled, Problem) /*@\label{tutorial-coupled:set-problem
 { typedef Dumux::TutorialProblemCoupled<TypeTag> type;};
 
 // Set grid and the grid creator to be used
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID /*@\label{tutorial-coupled:set-grid}@*/
+#if HAVE_DUNE_ALUGRID /*@\label{tutorial-coupled:set-grid}@*/
 SET_TYPE_PROP(TutorialProblemCoupled, Grid, Dune::ALUGrid</*dim=*/2, 2, Dune::cube, Dune::nonconforming>); /*@\label{tutorial-coupled:set-grid-ALU}@*/
 #elif HAVE_UG
 SET_TYPE_PROP(TutorialProblemCoupled, Grid, Dune::UGGrid<2>);
 #else
 SET_TYPE_PROP(TutorialProblemCoupled, Grid, Dune::YaspGrid<2>);
-#endif // HAVE_ALUGRID
+#endif // HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(TutorialProblemCoupled, GridCreator, Dumux::CubeGridCreator<TypeTag>); /*@\label{tutorial-coupled:set-gridcreator}@*/
 
 // Set the wetting phase
@@ -127,9 +125,9 @@ public:
         : ParentType(timeManager, gridView)
         , eps_(3e-6)
     {
-#if !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
-      std::cout << "If you want to use simplices instead of cubes, install and use ALUGrid or UGGrid." << std::endl;
-#endif // !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
+#if !(HAVE_DUNE_ALUGRID || HAVE_UG)
+      std::cout << "If you want to use simplices instead of cubes, install and use dune-ALUGrid or UGGrid." << std::endl;
+#endif // !(HAVE_DUNE_ALUGRID || HAVE_UG)
     }
 
     //! Specifies the problem name. This is used as a prefix for files
diff --git a/test/decoupled/2p2c/test_adaptive2p2c2d.cc b/test/decoupled/2p2c/test_adaptive2p2c2d.cc
index e69f60615a0838efa1b22a888c2202e27aab99fe..c4e2042e35a801f0d15f31fe9a01a9c41ad840b0 100644
--- a/test/decoupled/2p2c/test_adaptive2p2c2d.cc
+++ b/test/decoupled/2p2c/test_adaptive2p2c2d.cc
@@ -55,12 +55,12 @@ void usage(const char *progName, const std::string &errorMsg)
 // The main function using the standard start procedure
 int main(int argc, char** argv)
 {
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
     typedef TTAG(Adaptive2p2c2d) TypeTag;
     return Dumux::start<TypeTag>(argc, argv, usage);
 #else
-#warning ALUGrid needed for this test.
-    std::cerr << "ALUGrid needed for this test. Aborting." << std::endl;
+#warning dune-ALUGrid needed for this test.
+    std::cerr << "dune-ALUGrid needed for this test. Aborting." << std::endl;
     return 77;
 #endif
 }
diff --git a/tutorial/solutions_coupled/ex5_tutorialproblem_coupled.hh b/tutorial/solutions_coupled/ex5_tutorialproblem_coupled.hh
index 0c1ef5d30ddd2c0d89acad949e67360ff458d231..b4f3f2fb3f71bc6c733a3a9d989968e93d695c14 100644
--- a/tutorial/solutions_coupled/ex5_tutorialproblem_coupled.hh
+++ b/tutorial/solutions_coupled/ex5_tutorialproblem_coupled.hh
@@ -31,15 +31,13 @@
 #include <dumux/implicit/common/implicitporousmediaproblem.hh>
 
 // The DUNE grid used
-#if HAVE_ALUGRID
-#include <dune/grid/alugrid.hh>
-#elif HAVE_DUNE_ALUGRID
+#if HAVE_DUNE_ALUGRID
 #include <dune/alugrid/grid.hh>
 #elif HAVE_UG
 #include <dune/grid/uggrid.hh>
 #else
 #include <dune/grid/yaspgrid.hh>
-#endif // HAVE_ALUGRID, HAVE_UG
+#endif // HAVE_DUNE_ALUGRID, HAVE_UG
 
 // Spatially dependent parameters
 #include "ex5_tutorialspatialparams_coupled.hh"
@@ -63,14 +61,14 @@ SET_PROP(Ex5TutorialProblemCoupled, Problem) /*@\label{tutorial-coupled:set-prob
 { typedef Dumux::Ex5TutorialProblemCoupled<TypeTag> type;};
 
 // Set grid and the grid creator to be used
-#if HAVE_ALUGRID || HAVE_DUNE_ALUGRID /*@\label{tutorial-coupled:set-grid}@*/
+#if HAVE_DUNE_ALUGRID /*@\label{tutorial-coupled:set-grid}@*/
 SET_TYPE_PROP(Ex5TutorialProblemCoupled, Grid, Dune::ALUGrid</*dim=*/2, 2, Dune::cube, Dune::nonconforming>); /*@\label{tutorial-coupled:set-grid-ALU}@*/
 #elif HAVE_UG
 SET_TYPE_PROP(Ex5TutorialProblemCoupled, Grid, Dune::UGGrid<2>);
 #else
 SET_TYPE_PROP(Ex5TutorialProblemCoupled, Grid, Dune::YaspGrid<2>);
 #warning If you want to use adaptivity, install and use ALUGrid.
 #endif // HAVE_ALUGRID
 SET_TYPE_PROP(Ex5TutorialProblemCoupled, GridCreator, Dumux::CubeGridCreator<TypeTag>); /*@\label{tutorial-coupled:set-gridcreator}@*/
 
 // Set the wetting phase
@@ -126,9 +124,9 @@ public:
         : ParentType(timeManager, gridView)
         , eps_(3e-6)
     {
-#if !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
-      std::cout << "If you want to use simplices instead of cubes, install and use ALUGrid or UGGrid." << std::endl;
-#endif // !(HAVE_ALUGRID || HAVE_DUNE_ALUGRID || HAVE_UG)
+#if !(HAVE_DUNE_ALUGRID || HAVE_UG)
+      std::cout << "If you want to use simplices instead of cubes, install and use dune-ALUGrid or UGGrid." << std::endl;
+#endif // !(HAVE_DUNE_ALUGRID || HAVE_UG)
     }
 
     //! Specifies the problem name. This is used as a prefix for files
@@ -63,14 +61,14 @@ SET_PROP(Ex5TutorialProblemCoupled, Problem) /*@\label{tutorial-coupled:set-prob
 #else
 SET_TYPE_PROP(Ex5TutorialProblemCoupled, Grid, Dune::YaspGrid<2>);
-#warning If you want to use adaptivity, install and use ALUGrid.
-#endif // HAVE_ALUGRID
+#warning If you want to use adaptivity, install and use dune-ALUGrid.
+#endif // HAVE_DUNE_ALUGRID
 SET_TYPE_PROP(Ex5TutorialProblemCoupled, GridCreator, Dumux::CubeGridCreator<TypeTag>); /*@\label{tutorial-coupled:set-gridcreator}@*/
 